#!/bin/bash

#
# packager         : sebastian <zenwalkuser> seb@seb2.dyndns.org
#
# source location  :
# http://downloads.sourceforge.net/rezound/rezound-0.12.3beta.tar.gz?modtime=1125916285&big_mirror=0
#
#
# last revised     : 30/09/2007
#
# additional files : requires fox toolkit, fftw and soundtouch
#

_error() {
  echo -e $1
  echo -e "\nSee $soft-install.log for errors"
  exit 1
}

soft='rezound'
softversion='0.12.3.b'
packageversion='48.1'

arch='i486'
cpu='i686'
makeopts='-j2'

buildir=$(pwd)
srcpkg="$buildir/$soft-0.12.3beta.tar.gz"
src="$buildir/$soft-0.12.3beta"
srcuri="http://downloads.sourceforge.net/rezound/rezound-0.12.3beta.tar.gz?modtime=1125916285&big_mirror=0"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

echo "------------------------------------------------"
echo "Build package: $soft $softversion"
echo "------------------------------------------------"

cd $buildir
rm -rf $src
if [ ! -f $srcpkg ]; then
  echo "- Download source..."
  wget --passive --quiet $srcuri || _error "\tDownload failed!"
fi 
echo "- Unpacking source..."
tar -xzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS=$CFLAGS

cd $src
chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

echo "- Configuring package..."
cd $src
cat <<__EOF__ | patch -p1
--- rezound-0.12.3beta/src/backend/CFLACSoundTranslator.cpp	2005-05-01 06:39:38.000000000 +0200
+++ rezound-0.12.3beta-new/src/backend/CFLACSoundTranslator.cpp	2007-02-03 00:18:11.000000000 +0100
@@ -42,6 +42,12 @@
 #include "CSound.h"
 #include "AStatusComm.h"
 
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
+#define LEGACY_FLAC
+#else
+#undef LEGACY_FLAC
+#endif
+
 CFLACSoundTranslator::CFLACSoundTranslator()
 {
 }
@@ -75,15 +81,23 @@
 		for(unsigned t=0;t<MAX_CHANNELS;t++)
 			accessers[t]=NULL;
 
+#ifdef LEGACY_FLAC
 		set_filename(filename.c_str());
+#endif
 
 		set_metadata_ignore_all();
 		//set_metadata_respond(FLAC__METADATA_TYPE_VORBIS_COMMENT);
 		//set_metadata_respond(FLAC__METADATA_TYPE_CUESHEET);
 
+#ifdef LEGACY_FLAC
 		State s=init();
 		if(s!=FLAC__FILE_DECODER_OK)
 			throw runtime_error(string(__func__)+" -- "+s.as_cstring());
+#else
+		FLAC__StreamDecoderInitStatus s=init(filename.c_str());
+		if(s!=FLAC__STREAM_DECODER_INIT_STATUS_OK)
+			throw runtime_error(string(__func__)+" -- FLAC__STREAM_DECODER_INIT_STATUS not OK");
+#endif
 	}
 
 	virtual ~MyFLACDecoderFile()
@@ -170,7 +184,11 @@
 
 		// update status bar and detect user cancel
 		FLAC__uint64 filePosition;
+#ifdef LEGACY_FLAC
 		FLAC__file_decoder_get_decode_position(decoder_, &filePosition);
+#else
+		FLAC__stream_decoder_get_decode_position(decoder_, &filePosition);
+#endif
 		return statusBar.update(filePosition) ? FLAC__STREAM_DECODER_WRITE_STATUS_ABORT : FLAC__STREAM_DECODER_WRITE_STATUS_CONTINUE;
 	}
 
@@ -215,7 +233,11 @@
 bool CFLACSoundTranslator::onLoadSound(const string filename,CSound *sound) const
 {
 	MyFLACDecoderFile f(filename,sound);
+#ifdef LEGACY_FLAC
 	return f.process_until_end_of_file();
+#else
+	return f.process_until_end_of_stream();
+#endif	
 }
 
 
@@ -258,7 +280,9 @@
 
 	MyFLACEncoderFile f(saveLength);
 
+#ifdef LEGACY_FLAC
 	f.set_filename(filename.c_str());
+#endif
 
 	f.set_channels(sound->getChannelCount());
 
@@ -274,8 +298,13 @@
 	//f.set_metadata(...) // ??? to do to set cues and user notes, etc
 
 
+#ifdef LEGACY_FLAC
 	MyFLACEncoderFile::State s=f.init();
 	if(s==FLAC__STREAM_ENCODER_OK)
+#else
+	FLAC__StreamEncoderInitStatus s=f.init(filename.c_str());
+	if(s==FLAC__STREAM_ENCODER_INIT_STATUS_OK)
+#endif
 	{
 		#define BUFFER_SIZE 65536
 		TAutoBuffer<FLAC__int32> buffers[MAX_CHANNELS];
@@ -328,7 +357,11 @@
 		return true;
 	}
 	else
+#ifdef LEGACY_FLAC
 		throw runtime_error(string(__func__)+" -- error creating FLAC encoder -- "+s.as_cstring());
+#else
+		throw runtime_error(string(__func__)+" -- error creating FLAC encoder -- ");
+#endif
 
 }
 
__EOF__

    ./configure --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --disable-libFLACtest \
    --disable-libFLACPPtest \
    --with-FOX_1_6-include=/usr/include/fox-1.6 \
    --with-FOX_1_6-path=/usr/lib > ../$soft-install.log

echo "- Compiling package..."
make $makeopts >> ../$soft-install.log 2>&1 || _error "\tCompile failed"
echo "- Install package from temp directory"
make install DESTDIR=$dest >> ../$soft-install.log

echo "- Stripped all binaries and gzipping man pages..."
( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
#( cd $dest/usr/man
#  find . -name "*.?" | xargs gzip -9
#)

echo "- Copying documentation..."
mkdir -p $dest/usr/doc/$soft-$softversion
cp -af \
  README* ABOUT* $dest/usr/doc/$soft-$softversion
cp -af $src/docs $dest/usr/doc/$soft-$softversion
cp -af $dest/usr/doc/$soft $dest/usr/doc/$soft-$softversion
rm -fr $dest/usr/doc/$soft

mkdir -p $dest/install
cat > $dest/install/slack-desc <<END
   |-----handy-ruler------------------------------------------------------|
$soft: rezound - a grafical audio editor
$soft:
$soft: 
$soft: a full featured graphical 
$soft: audio file editor for Linux.
$soft: 
$soft: 
$soft:
$soft: 
$soft:
$soft: Build for Zenwalk
END

mkdir -p $dest/usr/share/applications

#
# generate the desktop file, see below for the icon file
#
cat <<"EOF" >$dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Exec=rezound
Icon=/usr/share/rezound/icon_logo_32.gif
MimeType=audio/x-scpls;audio/x-mpegurl;audio/mpegurl;audio/mp3;audio/x-mp3;audio/mpeg;audio/x-mpeg;audio/x-wav;application/x-ogg
Categories=Application;GTK;AudioVideo;Player;
Terminal=false
Type=Application
Encoding=UTF-8
Name=Rezound
Comment=grafical audio editor
EOF


mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

#
# update the dynamic libraries
#
#cat << "EOF" > $dest/install/doinst.sh
#/sbin/ldconfig
#EOF


cd $dest

# creating package
echo "- Creating $soft package..."
makepkg -l y -c y $dest.tgz > /dev/null 2>&1
cd $buildir
md5sum $package.tgz > $dest.md5

echo "- Deleting temporary directory's..."
rm -rf $src
rm -rf $dest

echo "Package created complete."
exit 0
